<?php

namespace Drupal\migrate_default_content_export\FieldProcessor;

use Drupal\Core\Config\Entity\ConfigEntityStorageInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\migrate_default_content_export\FieldProcessorBase;

/**
 * An entity reference field processor.
 */
class EntityReferenceFieldProcessor extends FieldProcessorBase {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(ContentEntityInterface $entity, string $field_name, FieldDefinitionInterface $field_definition): bool {
    // Entity reference and entity reference revisions fields are applicable.
    $is_entity_reference = $field_definition->getType() === 'entity_reference';
    $is_entity_reference_revisions = $field_definition->getType() === 'entity_reference_revisions';

    // If the field is not an entity reference or entity reference revisions
    // field, return false.
    if (!($is_entity_reference || $is_entity_reference_revisions)) {
      return FALSE;
    }

    // Entity reference fields that are referencing users are not applicable.
    // This is due to not exporting the anonymous or super admin user.
    $settings = $field_definition->getSettings();
    $is_not_user = !empty($settings['target_type']) && $settings['target_type'] !== 'user';

    return $is_not_user;
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(ContentEntityInterface $entity, string $field_name, FieldDefinitionInterface $field_definition): mixed {
    $value = $entity->get($field_name)->getValue();

    return self::process($value, $field_definition);
  }

  /**
   * {@inheritdoc}
   */
  protected function process(mixed $value, FieldDefinitionInterface $field_definition): mixed {
    $value = reset($value);

    // If the value is empty, return NULL.
    if (empty($value['target_id'])) {
      return NULL;
    }

    // Get the storage related to the target type for processing.
    $settings = $field_definition->getSettings();

    $entity_storage = \Drupal::entityTypeManager()->getStorage($settings['target_type']);

    // If the target type is a config entity, return as-is.
    // Otherwise, return the uuid of the target entity.
    if ($entity_storage instanceof ConfigEntityStorageInterface) {
      return $value['target_id'];
    }

    $target_entity = $entity_storage->load($value['target_id']);

    if (empty($target_entity)) {
      return NULL;
    }

    return $target_entity->uuid();
  }

}
