<?php

namespace Drupal\migrate_default_content_export\FieldProcessor;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\migrate_default_content_export\FieldProcessorBase;

/**
 * An integer field processor.
 */
class IntegerFieldProcessor extends FieldProcessorBase {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(ContentEntityInterface $entity, string $field_name, FieldDefinitionInterface $field_definition): bool {
    // Integer fields are applicable.
    return $field_definition->getType() === 'integer';
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(ContentEntityInterface $entity, string $field_name, FieldDefinitionInterface $field_definition): mixed {
    $value = $entity->get($field_name)->getValue();

    return self::process($value, $field_definition);
  }

  /**
   * {@inheritdoc}
   */
  protected function process(mixed $value, FieldDefinitionInterface $field_definition): mixed {
    $value = reset($value);

    // If the value is empty, return 0.
    if (empty($value['value'])) {
      return 0;
    }

    return $value['value'];
  }

}
