<?php

namespace Drupal\migrate_default_content_export\FieldProcessor;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\migrate_default_content_export\FieldProcessorBase;

/**
 * A path field processor.
 */
class PathFieldProcessor extends FieldProcessorBase {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(ContentEntityInterface $entity, string $field_name, FieldDefinitionInterface $field_definition): bool {
    // Path fields are applicable.
    return $field_definition->getType() === 'path';
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(ContentEntityInterface $entity, string $field_name, FieldDefinitionInterface $field_definition): mixed {
    $value = $entity->get($field_name)->getValue();

    return self::process($value, $field_definition);
  }

  /**
   * {@inheritdoc}
   */
  protected function process(mixed $value, FieldDefinitionInterface $field_definition): mixed {
    $value = reset($value);

    // If the value is empty or there is no alias, return NULL.
    if (empty($value) || !isset($value['alias'])) {
      return NULL;
    }

    // Remove the path id.
    unset($value['pid']);

    return $value;
  }

}
