<?php

namespace Drupal\migrate_default_content_export;

use Drupal\Core\Field\FieldDefinitionInterface;

/**
 * Provides a base implementation for a FieldProcessor.
 */
abstract class FieldProcessorBase implements FieldProcessorInterface {

  /**
   * Process the value of a field to retrieve the raw value.
   *
   * @param mixed $value
   *   The value to process.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The field definition of the field to process.
   *
   * @return mixed
   *   The processed value.
   */
  protected function process(mixed $value, FieldDefinitionInterface $field_definition): mixed {
    $value = reset($value);

    // If the value is empty, return NULL.
    if (empty($value['value'])) {
      return NULL;
    }

    return $value['value'];
  }

}
